[![coverage report](https://git.uibk.ac.at/geometrie-vermessung/biquaternion_py/badges/master/coverage.svg)](https://git.uibk.ac.at/geometrie-vermessung/biquaternion_py/-/commits/master)
[![pipeline status](https://git.uibk.ac.at/geometrie-vermessung/biquaternion_py/badges/master/pipeline.svg)](https://git.uibk.ac.at/geometrie-vermessung/biquaternion_py/-/commits/master)
[![Documentation Status](https://readthedocs.org/projects/biquaternion-py/badge/?version=latest)](https://biquaternion-py.readthedocs.io/en/latest/?badge=latest)
[![latest_release](https://git.uibk.ac.at/geometrie-vermessung/biquaternion_py/-/badges/release.svg)](https://git.uibk.ac.at/geometrie-vermessung/biquaternion_py/-/badges/release.svg?order_by=release_at)]

# biquaternion_py

This package implements the biquaternion algebra in python in a sympy compatible way.
The user can therefore not only calculate numerically, but also symbolically.

# Installation

This package can be installed through the PyPi
```
pip install biquaternion_py
```
or by downloading the source, opening a terminal in this folder and installing it from there.
```
pip install -r requirements.py 
pip install -e .
```
